@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2010 by Jim Jozwiak.
+    Copyright (C) 1996-2014 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,11 +20,9 @@
 */
 
 #include "addfood.h"
-#include "meal.h"
 #include "options.h"
 #include "util.h"
 #include "db.h"
-#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
@@ -458,11 +456,11 @@ for ( ; ; )
  yn = '\0';
  header("NUT:  Add a Labeled Food");
  printf("\n      Change group of nutrients to view?\n\n\n");
-for (i = 0; i < (dv ? dv + 1 : MaxScreen); i++) printf("                    %d  --  %s\n\n",i+1,ScreenTitle[i]);
-spacer((dv ? dv  + 1: MaxScreen) * 2 + 4);
+for (i = 0; i < (dv ? dv + 1 : MAX_SCREEN); i++) printf("                    %d  --  %s\n\n",i+1,ScreenTitle[i]);
+spacer((dv ? dv  + 1: MAX_SCREEN) * 2 + 4);
 printf("\nEnter your choice (just <enter> to quit):  ");
 screen_choice = get_int();
-if (screen_choice < 1 || screen_choice > (dv ? dv + 1 : MaxScreen))
+if (screen_choice < 1 || screen_choice > (dv ? dv + 1 : MAX_SCREEN))
 {
 while (yn != 'Y' && yn != 'y' && yn != 'N' && yn != 'n')
 {
@@ -557,7 +555,7 @@ else *dest = (atof(buff));
 
 void guess_recipe()
 {
-int i, j, savegramoption, cumlevel = 0, ok = 0;
+int i, j, savegramoption, cumlevel = 0, ok = 0, infloop = 1;
 int gt0dvnuts[DV_COUNT];
 int remaininggroupsassigner[DV_COUNT];
 int levelcumbuf[DV_COUNT] = {0,0,0,0,0,0,0,0,0,0,0,0};
@@ -592,7 +590,7 @@ for (i = GRfoodcount - 1; i >= 0; i--) cumlevel += parentheses[i];
 if (cumlevel != 0) parentheses[GRfoodcount - 1] -= cumlevel;
 cumlevel = 1;
 
-while (1)
+while (infloop)
  {
  for (i = GRfoodcount - 1; i >= 0; i--) if (parentheses[i] > -2 && parentheses[i] < 2) ok = 1;
  if (ok) break;
