@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2010 by Jim Jozwiak.
+    Copyright (C) 1996-2014 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,25 +20,30 @@
 */
 
 #include "anameal.h"
+#include "ranking.h"
+#include "trendy.h"
 #include "util.h"
 #include "db.h"
-#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <strings.h>
 #include <time.h>
 
+struct food *foodwork;
+int max;
+
 void analyze_meals(struct meal *meal_ptr_origin, int specialheader)
 {
 struct food *food_ptr, *food_ptr_abacus[MAX_FOOD];
 struct food *food_recommended[18];
 struct meal *meal_ptr;
-int max, meals, count, mealcount, meal = 0, deficnuts;
-int i, abacuscount, spacecount = 0, frcount, high_grams;
-char meal_date[9], inbuf[128];
-float newcal;
+int count, mealcount, deficnuts;
+int abacuscount, spacecount = 0, frcount, high_grams;
+char inbuf[128];
 float deficpct[DV_COUNT], food_abacus[MAX_FOOD], serving_ratio_abacus[MAX_FOOD];
 int deficnut[DV_COUNT];
 float prodefic, thispct, totaldefic, serving_ratio;
+foodwork = &food_work;
 options.temp_meal_root = meal_ptr_origin;
 mealcount = meal_count(meal_ptr_origin);
 max = mealcount;
@@ -56,29 +61,12 @@ if (mealcount == 0)
  }
 while (max > 0)
  {
- meal_ptr = meal_ptr_origin;
- strcpy(meal_date,"");
  if (max > mealcount) max = mealcount;
- meals = 0;
- clear_work();
- while (meal_ptr->next != NULL && meals <= max)
+ meal_ptr = load_foodwork(max, meal_ptr_origin);
+ if (options.screen == 0)
   {
-  meal_ptr = meal_ptr->next;
-  if (strcmp(meal_date,meal_ptr->meal_date) != 0 || meal != meal_ptr->meal)
-   {
-   strcpy(meal_date,meal_ptr->meal_date);
-   meal = meal_ptr->meal;
-   meals++;
-   }
-  if (meals > max) break;
-  for (count = 1; count <= *ScreenMap[options.screen] ; count++) if (! test_for_negative_zero(&FoodIndex[meal_ptr->food_no]->nutrient[ScreenMap[options.screen][count]])) food_work.nutrient[ScreenMap[options.screen][count]] = food_work.nutrient[ScreenMap[options.screen][count]] + ((options.mealsperday * meal_ptr->grams / 100 * FoodIndex[meal_ptr->food_no]->nutrient[ScreenMap[options.screen][count]]) / (float) max); 
-  food_work.nutrient[FAT_KCAL] += ((options.mealsperday * meal_ptr->grams / 100 * FoodIndex[meal_ptr->food_no]->nutrient[FAT_KCAL]) / (float) max);
-  food_work.nutrient[PROT_KCAL] += ((options.mealsperday * meal_ptr->grams / 100 * FoodIndex[meal_ptr->food_no]->nutrient[PROT_KCAL]) / (float) max);
-  food_work.nutrient[CHO_KCAL] += ((options.mealsperday * meal_ptr->grams / 100 * FoodIndex[meal_ptr->food_no]->nutrient[CHO_KCAL]) / (float) max);
-  food_work.nutrient[SHORT3] += ((options.mealsperday * meal_ptr->grams / 100 * FoodIndex[meal_ptr->food_no]->nutrient[SHORT3]) / (float) max);
-  food_work.nutrient[LONG3] += ((options.mealsperday * meal_ptr->grams / 100 * FoodIndex[meal_ptr->food_no]->nutrient[LONG3]) / (float) max);
-  food_work.nutrient[SHORT6] += ((options.mealsperday * meal_ptr->grams / 100 * FoodIndex[meal_ptr->food_no]->nutrient[SHORT6]) / (float) max);
-  food_work.nutrient[LONG6] += ((options.mealsperday * meal_ptr->grams / 100 * FoodIndex[meal_ptr->food_no]->nutrient[LONG6]) / (float) max);
+  auto_cal();
+  efa_dynamics();
   }
  if (specialheader == 1) header("NUT:  Record Meals");
  else header("NUT:  Analyze Meals");
@@ -95,76 +83,30 @@ while (max > 0)
  spacer(19);
  if ( options.screen == 0 )
   {
-  printf("Type # of meals to analyze,  \"s\" for food suggestions, \"c\" to reset calories,\n");
-  printf("\"m\" to reset macronutrients, \"e\" to reset everything,  \"o\" to restore defaults,\n");
-  printf("\"d\" for alternate displays,  or just press <enter> to quit:  ");
+  if (options.comparison) printf("\nType # of meals to analyze, \"s\" for food suggestions, \"o\" for normal mode,\n");
+  else printf("\nType # of meals to analyze, \"s\" for food suggestions, \"e\" for comparison mode,\n");
+  printf("\"d\" for alternate displays, \"p\" for previous, or <enter> to quit:  ");
   }
- if ( options.screen > 0 ) printf("\n\nType # of meals to analyze, \"d\" alternate displays, <enter> to quit: ");
+ if ( options.screen > 0 ) printf("\n\nType # meals to analyze, \"d\" alternate, \"p\" previous, <enter> to quit: ");
  get_string(inbuf,127);
- if (strncmp(inbuf,"c",1) == 0)
-  {
-  if (options.screen != 0) continue;
-  if (options.locknuts[ENERC_KCAL]) continue;
-  
-  newcal = food_work.nutrient[ENERC_KCAL];
-  if (!options.locknuts[FAT]) options.abnuts[FAT] = 0;
-  if (!options.locknuts[FAMS]) options.abnuts[FAMS] = 0;
-  if (options.abnuts[PROCNT]) options.pccarb = 0;
-  auto_cal(&newcal,1);
-  } 
+ if (strncmp(inbuf,"c",1) == 0) ;
  else if (strncmp(inbuf,"d",1) == 0) screen();
  else if (strncmp(inbuf,"p",1) == 0) screen_previous();
  else if (strncmp(inbuf,"e",1) == 0)
   {
-  if (options.screen != 0) continue;
-  restore_defaults(0);
-  for ( i = 1; i < DVMap[0]; i++) if ( !options.locknuts[DVMap[i+1]]) options.abnuts[DVMap[i+1]] = food_work.nutrient[DVMap[i+1]];
-  options.abnuts[FAMS] = 0;
-  if ( !options.locknuts[ENERC_KCAL] && !options.autocal) newcal = food_work.nutrient[ENERC_KCAL];
-  if (  options.locknuts[ENERC_KCAL] || options.autocal) newcal = DV[ENERC_KCAL];
-  if ( !options.locknuts[FASAT] ) options.pcsatfat = 10 * food_work.nutrient[FASAT] / DVBase[FASAT] * DVBase[ENERC_KCAL] / newcal;
-  auto_cal(&newcal,1);
+  options.comparison = 1;         
+  for (count = 1; count <= DV_COUNT; count++) DV[DVMap[count]] = food_work.nutrient[DVMap[count]];
   }
- else if (strncmp(inbuf,"m",1) == 0)
+ else if (strncmp(inbuf,"m",1) == 0) ;
+ else if (strncmp(inbuf,"o",1) == 0) 
   {
   if (options.screen != 0) continue;
-  restore_defaults(0);
-  if ( !options.locknuts[FIBTG]) options.abnuts[FIBTG] = food_work.nutrient[FIBTG];
-  if ( !options.locknuts[FASAT]) options.abnuts[FASAT] = food_work.nutrient[FASAT];
-  if ( !options.locknuts[PROCNT]) options.abnuts[PROCNT] = food_work.nutrient[PROCNT];
-  if ( !options.locknuts[CHOCDF]) options.abnuts[CHOCDF] = food_work.nutrient[CHOCDF];
-  if ( !options.locknuts[ENERC_KCAL] && !options.autocal) newcal = food_work.nutrient[ENERC_KCAL];
-  if (  options.locknuts[ENERC_KCAL] || options.autocal) newcal = DV[ENERC_KCAL];
-  if ( !options.locknuts[FASAT] ) options.pcsatfat = 10 * food_work.nutrient[FASAT] / DVBase[FASAT] * DVBase[ENERC_KCAL] / newcal;
-  auto_cal(&newcal,1);
-  }
- else if (strncmp(inbuf,"o",1) == 0)
-  {
-  if (options.screen != 0) continue;
-  restore_defaults(0);
-  }
- else if (strncmp(inbuf,"n",1) == 0)
-  {
-  if (options.screen != 0) continue;
-  restore_defaults(0);
-  if ( !options.locknuts[FIBTG]) options.abnuts[FIBTG] = food_work.nutrient[FIBTG];
-  if ( !options.locknuts[FASAT]) options.abnuts[FASAT] = food_work.nutrient[FASAT];
-  if ( !options.locknuts[ENERC_KCAL] && !options.autocal)
-   {
-   newcal = food_work.nutrient[ENERC_KCAL];
-   if ( !options.locknuts[PROCNT]) options.pcprotein = food_work.nutrient[PROT_KCAL] / food_work.nutrient[ENERC_KCAL] * 100;
-   if ( !options.locknuts[CHOCDF]) options.pccarb = food_work.nutrient[CHO_KCAL] / food_work.nutrient[ENERC_KCAL] * 100;
-   if ( !options.locknuts[FASAT] ) options.pcsatfat = 10 * food_work.nutrient[FASAT] / DVBase[FASAT] * DVBase[ENERC_KCAL] / newcal;
-   }
-  if (  options.locknuts[ENERC_KCAL] || options.autocal)
-   {
-   newcal = DV[ENERC_KCAL];
-   if ( !options.locknuts[PROCNT]) options.pcprotein = food_work.nutrient[PROT_KCAL] / DV[ENERC_KCAL] * 100;
-   if ( !options.locknuts[CHOCDF]) options.pccarb = food_work.nutrient[CHO_KCAL] / DV[ENERC_KCAL] * 100;
-   if ( !options.locknuts[FASAT] ) options.pcsatfat = 10 * food_work.nutrient[FASAT] / DVBase[FASAT] * DVBase[ENERC_KCAL] / newcal;
-   }
-  auto_cal(&newcal,1);
+  options.comparison = 0;
+  auto_cal();
+  efa_dynamics();
   }
+ else if (strncmp(inbuf,"n",1) == 0) ;
+ else if ((*inbuf >= 'A' && *inbuf <= 'Z') || index(inbuf,':') != NULL) thestory(inbuf);
  else if (strncmp(inbuf,"s",1) == 0)
   {
   if (options.screen != 0) continue;
@@ -179,7 +121,7 @@ while (max > 0)
       DVMap[count+1] == CHOLE || DVMap[count+1] == OMEGA6 ||
       DVMap[count+1] == CHO_NONFIB || DVMap[count+1] == OMEGA3 ||
       DVMap[count+1] == CHOCDF ||
-      (DVMap[count+1] == AA  && DV[AA] - 0.01 < .00001 && DV[EPA] - 0.01 < .00001 && DV[DHA] - 0.01 < .00001 ) ||
+      DVMap[count+1] == AA || DVMap[count+1] == LA ||
       (DVMap[count+1] == EPA && DV[AA] - 0.01 < .00001 && DV[EPA] - 0.01 < .00001 && DV[DHA] - 0.01 < .00001 ) ||
       (DVMap[count+1] == DHA && DV[AA] - 0.01 < .00001 && DV[EPA] - 0.01 < .00001 && DV[DHA] - 0.01 < .00001 ) ||
       food_work.nutrient[DVMap[count+1]] / DV[DVMap[count+1]] >= .9999) deficpct[count] = 0;
@@ -233,33 +175,7 @@ while (max > 0)
       serving_ratio = deficpct[count] / thispct;
       if (serving_ratio < serving_ratio_abacus[abacuscount] && serving_ratio * food_ptr->grams > 14) serving_ratio_abacus[abacuscount] = serving_ratio;
       }
-/*
-     if (strstr(food_ptr->name,"DEHYD") != NULL) high_grams = 114;
-     if (strstr(food_ptr->name,"DEHYDRATED") != NULL) high_grams = 114;
-     if (strstr(food_ptr->name,"DRY") != NULL) high_grams = 114;
-     if (strstr(food_ptr->name,"FROZEN DSSRT") != NULL) high_grams = 114;
-*/
-     if (strstr(food_ptr->name,"DRY") != NULL) serving_ratio_abacus[abacuscount] = 0;
-     if (strstr(food_ptr->name,"FREEZE-DRIED") != NULL) serving_ratio_abacus[abacuscount] = 0;
-     if (strstr(food_ptr->name,"DEHYD") != NULL) serving_ratio_abacus[abacuscount] = 0;
-     if (strstr(food_ptr->name,"ALASKA NATIVE") != NULL) serving_ratio_abacus[abacuscount] = 0;
-     if (strstr(food_ptr->name,"AK NATIVE") != NULL) serving_ratio_abacus[abacuscount] = 0;
-     if (strstr(food_ptr->name,"NAVAJO") != NULL) serving_ratio_abacus[abacuscount] = 0;
-     if (strstr(food_ptr->name,"SHOSHONE BANNOCK") != NULL) serving_ratio_abacus[abacuscount] = 0;
-     if (strstr(food_ptr->name,"PACIFIC NORTHWEST INDIANS") != NULL) serving_ratio_abacus[abacuscount] = 0;
-     if (strstr(food_ptr->name,"INST BRKFST PDR") != NULL) serving_ratio_abacus[abacuscount] = 0;
-     if (strstr(food_ptr->name,"INSTANT BREAKFAST") != NULL) serving_ratio_abacus[abacuscount] = 0;
-     if (strstr(food_ptr->name,"ENSURE") != NULL) serving_ratio_abacus[abacuscount] = 0;
-     if (strstr(food_ptr->name,"PROTEIN SUPPLEMENT") != NULL) serving_ratio_abacus[abacuscount] = 0;
-     if (strstr(food_ptr->name,"SOY PROTEIN ISOLATE") != NULL) serving_ratio_abacus[abacuscount] = 0;
-     if (strstr(food_ptr->name,"SOY PROTEIN CONC") != NULL) serving_ratio_abacus[abacuscount] = 0;
-     if (strstr(food_ptr->name,"MEAT EXTENDER") != NULL) serving_ratio_abacus[abacuscount] = 0;
-     if (strstr(food_ptr->name,"VITAMIN AND MINERAL FORTIFIED") != NULL) serving_ratio_abacus[abacuscount] = 0;
-     if (strstr(food_ptr->name,"EGG MIX,USDA COMMODITY") != NULL) serving_ratio_abacus[abacuscount] = 0;
-     if (strstr(food_ptr->name,"INDUSTRIAL") != NULL) serving_ratio_abacus[abacuscount] = 0;
-     if (strstr(food_ptr->name,"MEATLESS") != NULL) serving_ratio_abacus[abacuscount] = 0;
-     if (strstr(food_ptr->name,"MARGARINE") != NULL) high_grams = 14;
-     if (food_ptr->fdgrp == 2 || food_ptr->fdgrp == 3 || food_ptr->fdgrp == 8 || food_ptr->fdgrp == 14 || food_ptr->fdgrp == 19 || food_ptr->fdgrp == 25) serving_ratio_abacus[abacuscount] = 0;
+     if (food_ptr->fdgrp == 3 || food_ptr->fdgrp == 8 || food_ptr->fdgrp == 16 || food_ptr->fdgrp == 18 || food_ptr->fdgrp == 19 || food_ptr->fdgrp == 20 || food_ptr->fdgrp == 25 || food_ptr->fdgrp == 35) serving_ratio_abacus[abacuscount] = 0;
      if (serving_ratio_abacus[abacuscount] > 1 && high_grams == 114) serving_ratio_abacus[abacuscount] = 1;
      if ((serving_ratio_abacus[abacuscount] * food_ptr->grams) > high_grams) serving_ratio_abacus[abacuscount] = high_grams / food_ptr->grams;
      for (count = 0; count <= deficnuts; count++)
@@ -350,3 +266,12 @@ for (count = 0 ; count < last ; count++)
  }
 return i;
 }
+
+void thestory(const char *inbuf)
+{
+int i;
+for ( i = 1; i <= *ScreenMap[options.screen]; i++) if (strstr(Nutrient[ScreenMap[options.screen][i]],inbuf) != NULL) break;
+if (i > *ScreenMap[options.screen]) return;
+rank_foods(ScreenMap[options.screen][i],2);
+trendy('d',ScreenMap[options.screen][i]);
+}
