@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2010 by Jim Jozwiak.
+    Copyright (C) 1996-2014 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,12 +22,19 @@
 #ifndef ANAMEAL_H
 #define ANAMEAL_H
 
-#include "food.h"
-#include "meal.h"
 #include "options.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+ 
 void analyze_meals(struct meal *meal_ptr, int specialheader);
 void deficsort(float *, int *, int);
 int random_max_var_array(float [], int);
+void thestory(const char *);
+
+#ifdef __cplusplus
+} /* closing brace for extern "C" */
+#endif
 
 #endif
