@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2010 by Jim Jozwiak.
+    Copyright (C) 1996-2014 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,10 +20,9 @@
 */
 
 #include "db.h"
-#include "meal.h"
 #include "options.h"
 #include "util.h"
-#include <stdio.h>
+#include "recmeal.h"
 #include <stdlib.h>
 #include <string.h>
 #include <sys/stat.h>
@@ -35,13 +34,14 @@ char nutdir1[]=".nutdb";
 char nutdir1[]=NUTDIR ;
 #endif
 
-char USDAjoined1[] = "sr22.nut";
+char USDAjoined1[] = USDAVERSIONLC".nut";
 char globalFOOD1[] = "FOOD_DES.txt";
 char globalNUT1[] = "NUT_DATA.txt";
 char globalWEIGHT1[] = "WEIGHT.txt";
 char weightlib1[] = "WEIGHT.lib";
 char WLOG1[] = "WLOG.txt";
-char WLOGold1[] = "WLOG.old";
+char WLOGold1[] = "WLOG.";
+char WLOGaux1[] = "WLOG.aux";
 char localFOOD1[] = "FOOD_DES.txt";
 char localNUT1[] = "NUT_DATA.txt";
 char localWEIGHT1[] = "WEIGHT.txt";
@@ -53,7 +53,7 @@ char theusualfile1[] = "theusual.db";
 char optionsfile1[] = "options.db";
 char localOPTIONS1[] = "OPTIONS.txt";
 char versionfile1[] = "version";
-char oldversionfile1[] = ".version";
+char fontsizefile1[] = "fontsize";
 
 char USDAjoined[2000];
 char globalFOOD[2000];
@@ -62,6 +62,7 @@ char globalWEIGHT[2000];
 char weightlib[2000];
 char WLOG[2000];
 char WLOGold[2000];
+char WLOGaux[2000];
 char localFOOD[2000];
 char localNUT[2000];
 char localWEIGHT[2000];
@@ -73,21 +74,19 @@ char theusualfile[2000];
 char optionsfile[2000];
 char localOPTIONS[2000];
 char versionfile[2000];
-char oldversionfile[2000];
+char fontsizefile[2000];
 char nutdir[2000];
 char nutdirsubuser[2000];
 char subuser[2000];
 
 int mealdb_mealsperday;
 
-FILE *fp;
+FILE *fp, *fpaux;
 
 void read_food_files()
 {
- if (version(0) < 10) remove(optionsfile);
  read_joined_db(USDAjoined);
- if (version(0) == 10 && version(1) < 7) read_options_db(1);
- else read_OPTIONS(1);
+ read_OPTIONS(1);
  read_FOOD(globalFOOD);
  read_NUT(globalNUT);
  read_WEIGHT(globalWEIGHT);
@@ -101,13 +100,12 @@ void read_food_files()
  write_food_db();
  write_meal_db();
  write_theusual_db();
- read_OPTIONS(0);
  write_OPTIONS();
 }
 
 void read_joined_db(char *textfile) 
 {
-char buffer[800];
+char buffer[1200];
 char *bufptr;
 char *fieldptr;
 int count, junk, foodcount = 0;
@@ -120,9 +118,9 @@ if ((fp = fopen(textfile,"rb")) == NULL)
  }
 printf("\nReading food file \"%s\"\n",textfile);
 printf("to create food database \"%s\"...\n",foodfile);
-while (fgets(buffer,800,fp) != NULL)
+while (fgets(buffer,1200,fp) != NULL)
  {
- if ((new_food = malloc(sizeof(struct food))) == NULL)
+ if ((new_food = (struct food *)malloc(sizeof(struct food))) == NULL)
   {
   printf("We are out of memory.  Bummer.\n");
   abort();
@@ -174,7 +172,7 @@ while (fgets(buffer,800,fp) != NULL)
  fieldptr = bufptr;
  while (*bufptr != '^' ) bufptr++ ;
  *bufptr = '\0'; bufptr ++ ;
- strncpy(new_food->unit,fieldptr,50);
+ strncpy(new_food->unit,fieldptr,80);
  fieldptr = bufptr;
  while (*bufptr != '\n' ) bufptr++ ;
  *bufptr = '\0';
@@ -208,7 +206,7 @@ while (fgets(buffer,400,fp) != NULL)
  new_food = NULL;
  if (food_ptr == NULL)
   {
-  if ((new_food = malloc(sizeof(struct food))) == NULL)
+  if ((new_food = (struct food *)malloc(sizeof(struct food))) == NULL)
    {
    printf("We are out of memory.  Bummer.\n");
    abort();
@@ -418,7 +416,7 @@ struct food *food_ptr = &food_root;
 if ((fp = fopen(foodfile,"rb")) == NULL) return 0;
 for ( ; ; )
  {
- if ((new_food = malloc(sizeof(struct food))) == NULL)
+ if ((new_food = (struct food *)malloc(sizeof(struct food))) == NULL)
   {
   printf("Bad news.  We are out of memory...");
   abort();
@@ -427,6 +425,7 @@ for ( ; ; )
   {
   food_ptr->next = new_food;
   food_ptr = new_food;
+  food_ptr->pcf = ' ';
   foodcount++;
   }
  else break;
@@ -448,7 +447,7 @@ if ((fp = fopen(mealfile,"rb")) == NULL)
 mealdb_mealsperday = 0;
 for ( ; ; )
  {
- if ((new_meal = malloc(sizeof(struct meal))) == NULL)
+ if ((new_meal = (struct meal *)malloc(sizeof(struct meal))) == NULL)
   {
   printf("Bad news.  We are out of memory...");
   abort();
@@ -475,7 +474,7 @@ if ((fp = fopen(theusualfile,"rb")) == NULL)
  }
 for ( ; ; )
  {
- if ((new_theusual = malloc(sizeof(struct meal))) == NULL)
+ if ((new_theusual = (struct meal *)malloc(sizeof(struct meal))) == NULL)
   {
   printf("Bad news.  We are out of memory...");
   abort();
@@ -695,22 +694,18 @@ if ((fp = fopen(localOPTIONS,"wb")) == NULL)
 fprintf(fp,"%d^%d^\n",DELOPT,options.delopt);
 fprintf(fp,"%d^%d^\n",DEFANAL,options.defanal);
 fprintf(fp,"%d^%d^\n",SCREEN,options.screen);
-fprintf(fp,"%d^%d^\n",CUSTOM,options.custom);
-fprintf(fp,"%d^%f^\n",PCPROTEIN,options.pcprotein);
-fprintf(fp,"%d^%f^\n",PCCARB,options.pccarb);
-fprintf(fp,"%d^%f^\n",PCSATFAT,options.pcsatfat);
 fprintf(fp,"%d^%d^\n",NEXT_RECIPE,options.next_recipe);
 fprintf(fp,"%d^%d^\n",MEALSPERDAY,options.mealsperday);
 fprintf(fp,"%d^%d^\n",GRAMS,options.grams);
 fprintf(fp,"%d^%d^\n",AUTOCAL,options.autocal);
-fprintf(fp,"%d^%f^\n",PROTCALPERGM,options.protcalpergm);
-fprintf(fp,"%d^%f^\n",CARBCALPERGM,options.carbcalpergm);
-fprintf(fp,"%d^%f^\n",FATCALPERGM,options.fatcalpergm);
-fprintf(fp,"%d^%f^\n",FATTYACIDFACTOR,options.fattyacidfactor);
 fprintf(fp,"%d^%f^\n",N6HUFA,options.n6hufa);
-fprintf(fp,"%d^%f^\n",EPADHAMAX,options.epadhamax);
 fprintf(fp,"%d^%d^\n",DEFANALANAL,options.defanalanal);
 fprintf(fp,"%d^%d^\n",DEFANALREC,options.defanalrec);
+fprintf(fp,"%d^%f^\n",LASTWLW,options.lastwlw);
+fprintf(fp,"%d^%f^\n",LASTWLBFP,options.lastwlbfp);
+fprintf(fp,"%d^%s^\n",LASTWLDATE,options.lastwldate);
+fprintf(fp,"%d^%d^\n",WLTWEAK,options.wltweak);
+fprintf(fp,"%d^%d^\n",WLPOLARITY,options.wlpolarity);
 for (i = 1; i <= DV_COUNT; i++)
  {
  switch (DVMap[i])
@@ -736,52 +731,25 @@ for (i = 1; i <= DV_COUNT; i++)
   default         : field = LookupNutrNo[DVMap[i]];
                     break;
   }
- fprintf(fp,"%d^%f^%d\n",field,options.abnuts[DVMap[i]],options.locknuts[DVMap[i]]);
+ fprintf(fp,"%d^%f^\n",field,options.abnuts[DVMap[i]]);
  }
 fclose(fp);
 }
 
-void read_options_db(int dontwrite)
-{
-int block, need_to_find_next_recipe = 0;
-struct food *food_ptr = &food_root;
-initialize_options();
-if ((fp = fopen(optionsfile,"rb")) == NULL) 
- {
- write_OPTIONS();
- if (! dontwrite) need_to_find_next_recipe = 1;
- }
-if ((fp = fopen(optionsfile,"rb")) == NULL) 
- {
- printf("Can't open options database \"%s\" to read.\n",optionsfile);
- printf("Press <enter> to continue...");
- block = get_int();
- abort();
- }
-fread(&options,sizeof(struct opt),1,fp);
-fclose(fp);
-remove(optionsfile);
-options.temp_meal_root = &meal_root;
-auto_cal(&options.abnuts[ENERC_KCAL],0);
-delete_meals(options.delopt);
-if (! dontwrite) write_meal_db();
-if (need_to_find_next_recipe) while (food_ptr->next != NULL)
- {
- food_ptr = food_ptr->next;
- if (food_ptr->ndb_no >= options.next_recipe) options.next_recipe = food_ptr->ndb_no + 1;
- }
-}
-
 void read_OPTIONS(int dontwrite)
 {
-int block, need_to_find_next_recipe = 0, field;
+int block, field;
 char buffer[101], valbuf1[51], valbuf2[51];
 struct food *food_ptr = &food_root;
 initialize_options();
 if ((fp = fopen(localOPTIONS,"rb")) == NULL) 
  {
+ while (food_ptr->next != NULL)
+  {
+  food_ptr = food_ptr->next;
+  if (food_ptr->ndb_no >= options.next_recipe) options.next_recipe = food_ptr->ndb_no + 1;
+  }
  write_OPTIONS();
- if (! dontwrite) need_to_find_next_recipe = 1;
  }
 if ((fp = fopen(localOPTIONS,"rb")) == NULL) 
  {
@@ -803,14 +771,6 @@ while (fgets(buffer,100,fp) != NULL)
                         break;
   case SCREEN         : options.screen = atoi(valbuf1);
                         break;
-  case CUSTOM         : options.custom = atoi(valbuf1);
-                        break;
-  case PCPROTEIN      : options.pcprotein = atof(valbuf1);
-                        break;
-  case PCCARB         : options.pccarb = atof(valbuf1);
-                        break;
-  case PCSATFAT       : options.pcsatfat = atof(valbuf1);
-                        break;
   case NEXT_RECIPE    : options.next_recipe = atoi(valbuf1);
                         break;
   case MEALSPERDAY    : options.mealsperday = atoi(valbuf1);
@@ -819,128 +779,129 @@ while (fgets(buffer,100,fp) != NULL)
                         break;
   case AUTOCAL        : options.autocal = atoi(valbuf1);
                         break;
-  case PROTCALPERGM   : options.protcalpergm = atof(valbuf1);
-                        break;
-  case CARBCALPERGM   : options.carbcalpergm = atof(valbuf1);
-                        break;
-  case FATCALPERGM    : options.fatcalpergm = atof(valbuf1);
-                        break;
-  case FATTYACIDFACTOR : options.fattyacidfactor = atof(valbuf1);
-                        break;
   case N6HUFA          : options.n6hufa = atof(valbuf1);
                         break;
-  case EPADHAMAX       : options.epadhamax = atof(valbuf1);
-                        break;
   case DEFANALANAL     : options.defanalanal = atoi(valbuf1);
                         break;
   case DEFANALREC      : options.defanalrec = atoi(valbuf1);
                         break;
+  case LASTWLW         : options.lastwlw = atof(valbuf1);
+                        break;
+  case LASTWLBFP       : options.lastwlbfp = atof(valbuf1);
+                        break;
+  case LASTWLDATE      : sprintf(options.lastwldate,"%s",valbuf1);
+                        break;
+  case WLTWEAK         : options.wltweak = atoi(valbuf1);
+                        break;
+  case WLPOLARITY      : options.wlpolarity = atoi(valbuf1);
+                        break;
   case OPT_CHO_NONFIB : options.abnuts[CHO_NONFIB] = atof(valbuf1);
-                        options.locknuts[CHO_NONFIB] = atoi(valbuf2);
                         break;
   case OPT_LA         : options.abnuts[LA] = atof(valbuf1);
-                        options.locknuts[LA] = atoi(valbuf2);
                         break;
   case OPT_AA         : options.abnuts[AA] = atof(valbuf1);
-                        options.locknuts[AA] = atoi(valbuf2);
                         break;
   case OPT_ALA        : options.abnuts[ALA] = atof(valbuf1);
-                        options.locknuts[ALA] = atoi(valbuf2); 
                         break;
   case OPT_EPA        : options.abnuts[EPA] = atof(valbuf1);
-                        options.locknuts[EPA] = atoi(valbuf2);
                         break;
   case OPT_DHA        : options.abnuts[DHA] = atof(valbuf1);
-                        options.locknuts[DHA] = atoi(valbuf2);
                         break;
   case OPT_OMEGA6     : options.abnuts[OMEGA6] = atof(valbuf1);
-                        options.locknuts[OMEGA6] = atoi(valbuf2);
                         break;
   case OPT_OMEGA3     : options.abnuts[OMEGA3] = atof(valbuf1);
-                        options.locknuts[OMEGA3] = atoi(valbuf2);
                         break;
   case OPT_VITE       : options.abnuts[VITE] = atof(valbuf1);
-                        options.locknuts[VITE] = atoi(valbuf2);
                         break;
   default             : options.abnuts[LookupNut[field]] = atof(valbuf1); 
-                        options.locknuts[LookupNut[field]] = atoi(valbuf2); 
                         break;
   }
  }
 fclose(fp);
 options.temp_meal_root = &meal_root;
-auto_cal(&options.abnuts[ENERC_KCAL],0);
 delete_meals(options.delopt);
+DVnotOK = 1;
 if (! dontwrite) write_meal_db();
-if (need_to_find_next_recipe) while (food_ptr->next != NULL)
- {
- food_ptr = food_ptr->next;
- if (food_ptr->ndb_no >= options.next_recipe) options.next_recipe = food_ptr->ndb_no + 1;
- }
 }
 
-void read_WLOG(int *n, int *fatn, int *up, float *weightslope, float *fatslope)
+void read_WLOG(int *n, int *fatn, float *weightslope, float *fatslope, float *weightyintercept, float *fatyintercept, float *earliestrdate)
 {
 char buffer[101];
-float weight, bf, stardate;
+float weight, bf, relativedate;
 float fat;
 float sumweightx = 0, sumweighty = 0, sumweightxx = 0, sumweightxy = 0;
 float sumfatx = 0, sumfaty = 0, sumfatxx = 0, sumfatxy = 0; 
 
 *n = 0;
 *fatn = 0;
-*up = 1;
 if ((fp = fopen(WLOG,"rb")) == NULL) return;
+if ((fpaux = fopen(WLOGaux,"wb")) == NULL)
+ {
+ printf("Can't open weight log auxiliary file %s to write.\n",WLOGaux);
+ abort();
+ }
 while (fgets(buffer,100,fp) != NULL)                   
  {
  weight   = atof(strtok(buffer," "));
  bf       = atof(strtok(NULL," "));
- stardate = atof(strtok(NULL," "));
+ strncpy(options.lastwldate,strtok(NULL," "),9);
+ relativedate = (float) reverse_time_machine(options.lastwldate);
+ options.lastwlw = weight;
+ options.lastwlbfp = bf;
  (*n)++;
- sumweightx += stardate;
- sumweightxx += stardate * stardate;
+ sumweightx += relativedate;
+ sumweightxx += relativedate * relativedate;
  sumweighty += weight;
- sumweightxy += stardate * weight;
+ sumweightxy += relativedate * weight;
  fat = weight * bf / 100;
  if (fat > 0) 
   {
   (*fatn)++;
-   sumfatx += stardate;
-   sumfatxx += stardate * stardate;
-   sumfaty += fat;
-   sumfatxy += stardate * fat;
+  sumfatx += relativedate;
+  sumfatxx += relativedate * relativedate;
+  sumfaty += fat;
+  sumfatxy += relativedate * fat;
+  if (*fatn == 1) *earliestrdate = relativedate;
   }
+ sprintf(options.lastwldate,"%1.0f",relativedate);
+ time_machine(options.lastwldate);
+ fprintf(fpaux,"%3.1f %2.1f %s lean_mass=%2.2f fat_mass=%2.2f\n",weight,bf,options.lastwldate,weight-fat,fat);
  }
 fclose(fp);
+fclose(fpaux);
 *weightslope = (sumweightxy - (sumweightx * sumweighty / *n)) / (sumweightxx - (sumweightx * sumweightx / *n));
 if (*fatn > 1) 
  {
  *fatslope = (sumfatxy - (sumfatx * sumfaty / *fatn)) / (sumfatxx - (sumfatx * sumfatx / *fatn));
- if (*fatslope > 0) *up = 0;
- else if (options.autocal == 2 && *weightslope - *fatslope > 0) *up = 0;
- *fatslope = (float) (int) (1000 * *fatslope);
- *fatslope /= 1000;
+ *fatyintercept = sumfaty / *fatn - *fatslope * sumfatx / *fatn;
  }
-*weightslope = (float) (int) (1000 * *weightslope);
-*weightslope /= 1000;
+*weightyintercept = sumweighty / *n - *weightslope * sumweightx / *n;
 }
 
-void write_WLOG(float *weight, float *bf, float *stardate)
+void write_WLOG(float *weight, float *bf, char *meal_date)
 {
 char buffer[128];
+char today_date[9];
+char WLOGoldtoday[2000];
 int block, c;
-if (*weight == 0)
- {
- rename(WLOG,WLOGold);
- return;
- }
+today(today_date);
+sprintf(WLOGoldtoday,"%s%s",WLOGold,today_date);
+if (*weight == 0) rename(WLOG,WLOGoldtoday);
 if ((fp = fopen(WLOG,"ab")) == NULL)
  {
  printf("Can't open weight log file %s to append.\n",WLOG);
  abort();
  }
-sprintf(buffer,"%g %g %g\n",*weight,*bf,*stardate);
-c = strlen(buffer);
+if (*weight == 0)
+ {
+ sprintf(buffer,"%g %g %s\n",options.lastwlw,options.lastwlbfp,options.lastwldate);
+ c = strlen(buffer);
+ }
+else
+ {
+ sprintf(buffer,"%g %g %s\n",*weight,*bf,meal_date);
+ c = strlen(buffer);
+ }
 if ((block = fwrite(buffer,c,1,fp)) != 1)
  {
  printf("Cannot write to the disk.  Aborting...\n");
@@ -949,7 +910,7 @@ if ((block = fwrite(buffer,c,1,fp)) != 1)
 fclose(fp);
 }
 
-void make_filenames(char *sub)
+void make_filenames(const char *sub)
 {
 strcpy(subuser,sub);
 #ifdef DOS
@@ -957,13 +918,14 @@ strcpy(subuser,sub);
  mkdir (nutdir, 0700 );
  sprintf(nutdirsubuser,"%s/%s","NUTDB",subuser);
  mkdir (nutdirsubuser, 0700 );
- sprintf(USDAjoined,"%s/%s","NUTSR22",USDAjoined1);
- sprintf(globalFOOD,"%s/%s","NUTSR22",globalFOOD1);
- sprintf(globalNUT,"%s/%s","NUTSR22",globalNUT1);
- sprintf(globalWEIGHT,"%s/%s","NUTSR22",globalWEIGHT1);
- sprintf(weightlib,"%s/%s","NUTSR22",weightlib1);
- sprintf(WLOG,"%s/%s","NUTDB",WLOG1);
- sprintf(WLOGold,"%s/%s","NUTDB",WLOGold1);
+ sprintf(USDAjoined,"%s/%s","NUT"USDAVERSION,USDAjoined1);
+ sprintf(globalFOOD,"%s/%s","NUT"USDAVERSION,globalFOOD1);
+ sprintf(globalNUT,"%s/%s","NUT"USDAVERSION,globalNUT1);
+ sprintf(globalWEIGHT,"%s/%s","NUT"USDAVERSION,globalWEIGHT1);
+ sprintf(weightlib,"%s/%s","NUT"USDAVERSION,weightlib1);
+ sprintf(WLOG,"%s/%s/%s","NUTDB",subuser,WLOG1);
+ sprintf(WLOGold,"%s/%s/%s","NUTDB",subuser,WLOGold1);
+ sprintf(WLOGaux,"%s/%s/%s","NUTDB",subuser,WLOGaux1);
  sprintf(localFOOD,"%s/%s/%s","NUTDB",subuser,localFOOD1);
  sprintf(localNUT,"%s/%s/%s","NUTDB",subuser,localNUT1);
  sprintf(localWEIGHT,"%s/%s/%s","NUTDB",subuser,localWEIGHT1);
@@ -975,6 +937,7 @@ strcpy(subuser,sub);
  sprintf(optionsfile,"%s/%s/%s","NUTDB",subuser,optionsfile1);
  sprintf(localOPTIONS,"%s/%s/%s","NUTDB",subuser,localOPTIONS1);
  sprintf(versionfile,"%s/%s/%s","NUTDB",subuser,versionfile1);
+ sprintf(fontsizefile,"%s/%s/%s","NUTDB",subuser,fontsizefile1);
 #else
 sprintf(nutdir,"%s/%s",getenv("HOME"),nutdir1);
 mkdir (nutdir, 0700 );
@@ -987,6 +950,7 @@ sprintf(globalWEIGHT,"%s/%s",FOODDIR,globalWEIGHT1);
 sprintf(weightlib,"%s/%s",FOODDIR,weightlib1);
 sprintf(WLOG,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,WLOG1);
 sprintf(WLOGold,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,WLOGold1);
+sprintf(WLOGaux,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,WLOGaux1);
 sprintf(localFOOD,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,localFOOD1);
 sprintf(localNUT,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,localNUT1);
 sprintf(localWEIGHT,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,localWEIGHT1);
@@ -998,39 +962,10 @@ sprintf(theusualfile,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,theusualfile1)
 sprintf(optionsfile,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,optionsfile1);
 sprintf(localOPTIONS,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,localOPTIONS1);
 sprintf(versionfile,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,versionfile1);
-sprintf(oldversionfile,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,oldversionfile1);
-check_version_file();
+sprintf(fontsizefile,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,fontsizefile1);
 #endif
 }
 
-void check_version_file()
-{
-char release_string[9];
-int majrelease, minrelease, majreleasedot, minreleasedot;
-if ((fp = fopen(oldversionfile,"rb")) == NULL) return;
-fread(&release_string,8,1,fp);
-fclose(fp);
-majreleasedot = atoi(strtok(release_string,"."));
-minreleasedot = atoi(strtok(NULL,"."));
-remove(oldversionfile);
-if ((fp = fopen(versionfile,"rb")) == NULL)
- {
- if ((fp = fopen(versionfile,"wb")) == NULL) return;
- fprintf(fp,"%d.%d",majreleasedot,minreleasedot);
- fclose(fp);
- return;
- }
-fread(&release_string,8,1,fp);
-fclose(fp);
-majrelease = atoi(strtok(release_string,"."));
-minrelease = atoi(strtok(NULL,"."));
-if (majreleasedot < majrelease) return;
-if (majreleasedot == majrelease && minreleasedot <= minrelease) return;
-if ((fp = fopen(versionfile,"wb")) == NULL) return;
-fprintf(fp,"%d.%d",majreleasedot,minreleasedot);
-fclose(fp);
-}
-
 int version(int level)
 {
 char release_string[128];
@@ -1073,7 +1008,7 @@ if ((fp = fopen(mealexpfile,"w")) == NULL) return;
 while (meal_ptr->next != NULL)                    
  {
  meal_ptr = meal_ptr->next;
- fprintf(fp,"%s^%d^%d^%f\n",meal_ptr->meal_date,meal_ptr->meal,meal_ptr->ndb_no,
+ fprintf(fp,"%s^%d^%05d^%f\n",meal_ptr->meal_date,meal_ptr->meal,meal_ptr->ndb_no,
 meal_ptr->grams);
  }
 fclose(fp);
@@ -1083,9 +1018,40 @@ if ((fp = fopen(theusualexpfile,"w")) == NULL) return;
 while (meal_ptr->next != NULL)                    
  {
  meal_ptr = meal_ptr->next;
- fprintf(fp,"%s^%d^%d^%f\n",meal_ptr->meal_date,meal_ptr->meal,meal_ptr->ndb_no,
+ fprintf(fp,"%s^%d^%05d^%f\n",meal_ptr->meal_date,meal_ptr->meal,meal_ptr->ndb_no,
 meal_ptr->grams);
  }
 fclose(fp);
 return;
 }
+
+int fontsize(void)
+{
+char font_string[128];
+int fontsize;         
+if ((fp = fopen(fontsizefile,"rb")) == NULL)
+ {
+ write_fontsize(12);
+ return 12;
+ }
+fread(&font_string,8,1,fp);
+fclose(fp);                
+fontsize = atoi(font_string);
+if (fontsize > 24) return 24;
+else if (fontsize < 8) return 8;
+else return fontsize;
+}
+
+void write_fontsize(int pixels)
+{
+int block;
+if ((fp = fopen(fontsizefile,"wb")) == NULL)
+ {
+ printf("Can't write fontsize to disk in \"%s\".\n",fontsizefile);
+ printf("Press <enter> to continue...");
+ block = get_int();
+ abort();
+ }
+fprintf(fp,"%d\n", pixels);
+fclose(fp);
+}
