@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2010 by Jim Jozwiak.
+    Copyright (C) 1996-2014 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,14 +22,20 @@
 #ifndef DB_H
 #define DB_H
 
-#define MAJVERSION 15
-#define MINVERSION 5
-#define VERSIONQ "15.5"
+#define MAJVERSION 19
+#define MINVERSION 1
+#define VERSIONQ "19.1"
+#define USDAVERSION "SR26"
+#define USDAVERSIONLC "sr26"
 
-#include <stdio.h>
 #include "food.h"
 
 extern char subuser[];
+extern char nutdir[];
+
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 void read_food_files(void);
 void read_joined_db(char *);
@@ -46,14 +52,18 @@ void write_theusual_db(void);
 void write_OPTIONS(void);
 void write_recipe(struct food *);
 void write_serving(struct food *);
-void read_options_db(int);
 void read_OPTIONS(int);
-void read_WLOG(int *, int *, int *, float *, float *);
-void write_WLOG(float *, float *, float *);
-void make_filenames(char *);
+void read_WLOG(int *, int *, float *, float *, float *, float *, float *);
+void write_WLOG(float *, float *, char *);
+void make_filenames(const char *);
+int fontsize(void);
+void write_fontsize(int);
 int version(int);
 void write_version(void);
-void check_version_file(void);
 void meal_export(void);
 
+#ifdef __cplusplus
+} /* closing brace for extern "C" */
+#endif
+
 #endif
