@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2010 by Jim Jozwiak.
+    Copyright (C) 1996-2014 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,14 +19,11 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
-#include "food.h"
-#include "meal.h"
 #include "util.h"
 #include "options.h"
 #include "nutrient.h"
 #include "abbrev.h"
 #include "fdgrp.h"
-#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
@@ -37,30 +34,31 @@ int DVMap[] =
 {
 DV_COUNT,ENERC_KCAL,
 FAT,FASAT,FAMS,FAPU,OMEGA6,LA,AA,OMEGA3,ALA,EPA,DHA,CHOLE,CHOCDF,FIBTG,CHO_NONFIB,PROCNT,
-VITA_IU,THIA,RIBF,NIA,PANTAC,VITB6A,FOL,VITB12,VITC,VITD,VITE,VITK,
+VITA_IU,THIA,RIBF,NIA,PANTAC,VITB6A,FOL,VITB12,VITC,VITD,VITE,VITK1,
 CA,CU,FE,MG,MN,P,K,SE,NA,ZN
 };
 
 int CarbAminoMap[] =
 {
-31,CHOCDF,FIBTG,STARCH,SUGAR,FRUS,GALS,GLUS,LACS,MALS,SUCS,
+CARBAMINO_COUNT,CHOCDF,FIBTG,STARCH,SUGAR,FRUS,GALS,GLUS,LACS,MALS,SUCS,
 PROCNT,ADPROT,ALA_G,ARG_G,ASP_G,CYS_G,GLU_G,GLY_G,HISTN_G,HYP,ILE_G,
 LEU_G,LYS_G,MET_G,PHE_G,PRO_G,SER_G,THR_G,TRP_G,TYR_G,VAL_G
 };
 
 int MiscMap[] =
 {
-33,ENERC_KJ,ASH,WATER,CAFFN,THEBRN,ALC,
+MISC_COUNT,ENERC_KJ,ASH,WATER,CAFFN,THEBRN,ALC,
 FLD,BETN,CHOLN,FOLAC,FOLFD,FOLDFE,RETOL,VITA_RAE,
 ERGCAL,CHOCAL,VITD_BOTH,
 VITB12_ADDED,VITE_ADDED,
-TOCPHA,TOCPHB,TOCPHG,TOCPHD,CARTA,CARTB,CRYPX,LUT_ZEA,LYCPN,
+VITK1D,MK4,
+TOCPHA,TOCPHB,TOCPHG,TOCPHD,TOCTRA,TOCTRB,TOCTRG,TOCTRD,CARTA,CARTB,CRYPX,LUT_ZEA,LYCPN,
 CHOLE,PHYSTR,SITSTR,CAMD5,STID7
 };
 
 int SatMonoMap[] =
 {
-27,FASAT,F4D0,F6D0,F8D0,F10D0,F12D0,F13D0,F14D0,F15D0,F16D0,
+SATMONO_COUNT,FASAT,F4D0,F6D0,F8D0,F10D0,F12D0,F13D0,F14D0,F15D0,F16D0,
 F17D0,F18D0,F20D0,F22D0,F24D0,
 FAMS,F14D1,F15D1,F16D1,F16D1C,F17D1,
 F18D1,F18D1C,F20D1,F22D1,F22D1C,F24D1C
@@ -68,10 +66,12 @@ F18D1,F18D1C,F20D1,F22D1,F22D1C,F24D1C
 
 int PolyTransMap[] =
 {
-29,FAPU,F18D2,F18D2CN6,F18D3,F18D3CN3,F18D3CN6,F18D4,F20D2CN6,F20D3,
+POLYTRANS_COUNT,FAPU,F18D2,F18D2CN6,
+F18D3,F18D3CN3,F18D3CN6,F18D4,F20D2CN6,F20D3,
 F20D3N3,F20D3N6,
 F20D4,F20D4N6,F20D5,F21D5,F22D4,F22D5,F22D6,
-FATRN,FATRNM,F16D1T,F18D1T,F22D1T,FATRNP,F18D2T,F18D2TT,F18D2I,F18D2CLA,F18D3I
+FATRN,FATRNM,F16D1T,F18D1T,F18D1TN7,F22D1T,
+FATRNP,F18D2T,F18D2TT,F18D2I,F18D2CLA,F18D3I
 };
 
 int *ScreenMap[] =
@@ -86,14 +86,14 @@ char *ScreenTitle[] =
 "Saturated and Monounsaturated Fatty Acids","Polyunsaturated and Trans Fatty Acids"
 };
 
-int MaxScreen = 6;
-
 int MaxFdGrp = FD_GRP_COUNT;
 
 float DVBase[NUTRIENT_COUNT];
 
 float DV[NUTRIENT_COUNT];
 
+int DVnotOK;
+
 float NoData;
 
 int LookupNutrNo[NUTRIENT_COUNT - DERIVED];
@@ -106,6 +106,7 @@ void initializations()
 int c;
 NoData = atof("-0");
 test_signsense(&NoData);
+initialize_options();
 for (c=0; c < NUTRIENT_COUNT; c++) DVBase[c] = 0;
 
 DVBase[ENERC_KCAL] = 2000;
@@ -126,7 +127,7 @@ DVBase[MN] = 2;
 DVBase[SE] = 70;
 DVBase[VITA_IU] = 5000;
 DVBase[VITE] = 30;
-DVBase[VITK] = 80;
+DVBase[VITK1] = 80;
 DVBase[THIA] = 1.5;
 DVBase[RIBF] = 1.7;
 DVBase[NIA] = 20;
@@ -138,14 +139,14 @@ DVBase[VITC] = 60;
 DVBase[FASAT] = 20;
 DVBase[CHOLE] = 300;
 DVBase[VITD] = 400;
-DVBase[LA] = 9;
-DVBase[AA] = 0.16;
-DVBase[OMEGA6] = DVBase[LA] + DVBase[AA];
-DVBase[ALA] = DVBase[LA] / ALA_FACTOR;
-DVBase[EPA] = 0.3;
-DVBase[DHA] = 0.3;
+DVBase[FAPU] = 8.9;
+DVBase[AA] = 0.2;
+DVBase[ALA] = 3.8;
+DVBase[EPA] = 0.1;
+DVBase[DHA] = 0.1;
+DVBase[LA] = DVBase[FAPU] - DVBase[AA] - DVBase[ALA] - DVBase[EPA] - DVBase[DHA];
 DVBase[OMEGA3] = DVBase[ALA] + DVBase[EPA] + DVBase[DHA];
-DVBase[FAPU] = DVBase[OMEGA6] + DVBase[OMEGA3];
+DVBase[OMEGA6] = DVBase[LA] + DVBase[AA];
 DVBase[FAMS] = 61.5 - DVBase[FASAT] - DVBase[FAPU];
 for (c=0; c < NUTRNO_ARRAYSIZE; c++) LookupNut[c] = -1;
 for (c=0; c < NUTRIENT_COUNT - DERIVED; c++) LookupNutrNo[c] = -1;
@@ -166,14 +167,6 @@ food_ptr->next = new_food;
 return foodnum;
 }
 
-void order_new_food_already_sorted()
-{
-struct food *food_ptr = &food_root;
-while (food_ptr->next != NULL) food_ptr = food_ptr->next;
-new_food->next = NULL;
-food_ptr->next = new_food;
-}
-
 int namestrcmp(char *name1, char *name2)
 {
 char namebuf1[61], namebuf2[61];
@@ -593,7 +586,7 @@ void food_display(FILE *fp)
 int i, n6;
 float pctfat = 0, pctcarb = 0, pctprot = 0;
 float p3, p6, h3, h6, o;
-char carbprotfat[9];
+char protcarbfat[30];
 if (food_work.nutrient[ENERC_KCAL] > 0.05)
  {
  pctcarb = 100 * food_work.nutrient[CHO_KCAL] / food_work.nutrient[ENERC_KCAL];
@@ -607,14 +600,14 @@ else
  {
  pctcarb = 0; pctprot = 0; pctfat = 0;
  }
-sprintf(carbprotfat,"%1.0f/%1.0f/%1.0f",pctcarb,pctprot,pctfat);
+sprintf(protcarbfat,"%1.0f/%1.0f/%1.0f",pctprot,pctcarb,pctfat);
 switch (options.screen)
  {
  case 1 :
  food_display_line(fp,ScreenMap[options.screen][1],0,0,0,0);
  food_display_line(fp,ScreenMap[options.screen][14],0,0,0,0);
  food_display_line(fp,ScreenMap[options.screen][17],0,1,0,0);
- fprintf(fp,"Carb/Prot/Fat    %8s  ",carbprotfat);
+ fprintf(fp,"Prot/Carb/Fat    %8s  ",protcarbfat);
  food_display_line(fp,ScreenMap[options.screen][15],0,0,0,0);
  food_display_line(fp,ScreenMap[options.screen][16],0,1,0,0);
  fprintf(fp,"\n");
@@ -649,11 +642,11 @@ switch (options.screen)
  food_display_line(fp,ScreenMap[options.screen][i+16],0,1,0,0);
  food_display_line(fp,ScreenMap[options.screen][13],0,0,0,0);
  food_display_line(fp,ScreenMap[options.screen][13+16],0,0,0,0);
- p3 = 902 * food_work.nutrient[SHORT3] / food_work.nutrient[ENERC_KCAL];
- p6 = 902 * food_work.nutrient[SHORT6] / food_work.nutrient[ENERC_KCAL];
- h3 = 902 * food_work.nutrient[LONG3] / food_work.nutrient[ENERC_KCAL];
- h6 = 902 * food_work.nutrient[LONG6] / food_work.nutrient[ENERC_KCAL];
- o  = 902 * food_work.nutrient[FAT] * options.fattyacidfactor / food_work.nutrient[ENERC_KCAL] - food_work.nutrient[SHORT6] - food_work.nutrient[LONG6] - food_work.nutrient[SHORT3] - food_work.nutrient[LONG3];
+ p3 = 900 * food_work.nutrient[SHORT3] / food_work.nutrient[ENERC_KCAL];
+ p6 = 900 * food_work.nutrient[SHORT6] / food_work.nutrient[ENERC_KCAL];
+ h3 = 900 * food_work.nutrient[LONG3] / food_work.nutrient[ENERC_KCAL];
+ h6 = 900 * food_work.nutrient[LONG6] / food_work.nutrient[ENERC_KCAL];
+ o  = 900 * (food_work.nutrient[FASAT] + food_work.nutrient[FAMS] + food_work.nutrient[FAPU] - food_work.nutrient[SHORT6] - food_work.nutrient[LONG6] - food_work.nutrient[SHORT3] - food_work.nutrient[LONG3]) / food_work.nutrient[ENERC_KCAL];
  n6 = (int) n6hufa(p3,p6,h3,h6,o,food_work.nutrient[ENERC_KCAL]);
  fprintf(fp,"Omega-6/3 Balance %2d/%1d\n",n6 == 0 ? 0 : n6,n6 == 0 ? 0 : 100-n6);
  break;
@@ -678,13 +671,12 @@ switch (options.screen)
  break;
  case 3 :
  fprintf(fp,"Miscellaneous Nutrients\n\n");
- for (i = 1; i < 12 ; i++)
+ for (i = 1; i < 14 ; i++)
   {
   food_display_line(fp,ScreenMap[options.screen][i],0,0,0,0);
-  food_display_line(fp,ScreenMap[options.screen][i+11],0,0,0,0);
-  food_display_line(fp,ScreenMap[options.screen][i+22],0,1,0,0);
+  food_display_line(fp,ScreenMap[options.screen][i+13],0,0,0,0);
+  food_display_line(fp,ScreenMap[options.screen][i+26],0,1,0,0);
   }
- fprintf(fp,"\n\n");
  break;
  case 4 :
  food_display_line(fp,ScreenMap[options.screen][1],0,0,1,0);
@@ -705,12 +697,12 @@ switch (options.screen)
   food_display_line(fp,ScreenMap[options.screen][i+9],0,0,1,0);
   food_display_line(fp,ScreenMap[options.screen][i+18],0,1,1,0);
   }
- for (i = 10; i < 12 ; i++)
+ for (i = 10; i < 13 ; i++)
   {
   fprintf(fp,"%-54s"," ");
   food_display_line(fp,ScreenMap[options.screen][i+18],0,1,1,0);
   }
- fprintf(fp,"\n\n");
+ fprintf(fp,"\n");
  break;
  default :
  if (! test_for_negative_zero(&food_work.nutrient[ScreenMap[options.screen][1]])) fprintf(fp,"Calories(%4.0f)   %5.0f%%     ",DV[ScreenMap[options.screen][1]],food_work.nutrient[ScreenMap[options.screen][1]]/DV[ScreenMap[options.screen][1]]*100);
@@ -719,7 +711,7 @@ switch (options.screen)
  else fprintf(fp,"%-14s    %5s     ",Nutrient[ScreenMap[options.screen][14]],"(nd)");
  if (! test_for_negative_zero(&food_work.nutrient[ScreenMap[options.screen][17]])) fprintf(fp,"%-14s   %5.0f%%\n",Nutrient[ScreenMap[options.screen][17]],food_work.nutrient[ScreenMap[options.screen][17]]/DV[ScreenMap[options.screen][17]] *100);
  else fprintf(fp,"%-14s    %5s\n",Nutrient[ScreenMap[options.screen][17]],"(nd)");
- fprintf(fp,"Carb/Prot/Fat  %8s     ",carbprotfat);
+ fprintf(fp,"Prot/Carb/Fat  %8s     ",protcarbfat);
  food_display_line(fp,ScreenMap[options.screen][15],1,0,0,0);
  if (! test_for_negative_zero(&food_work.nutrient[ScreenMap[options.screen][16]])) fprintf(fp,"%-15s  %5.0f%-1s\n",Nutrient[ScreenMap[options.screen][16]],food_work.nutrient[ScreenMap[options.screen][16]],Unit[ScreenMap[options.screen][16]]);
  else fprintf(fp,"%-15s   %5s\n",Nutrient[ScreenMap[options.screen][16]],"(nd)");
@@ -760,11 +752,11 @@ switch (options.screen)
  food_display_line(fp,ScreenMap[options.screen][i+16],1,1,0,0);
  food_display_line(fp,ScreenMap[options.screen][13],1,0,0,0);
  food_display_line(fp,ScreenMap[options.screen][13+16],1,0,0,0);
- p3 = 902 * food_work.nutrient[SHORT3] / food_work.nutrient[ENERC_KCAL];
- p6 = 902 * food_work.nutrient[SHORT6] / food_work.nutrient[ENERC_KCAL];
- h3 = 902 * food_work.nutrient[LONG3] / food_work.nutrient[ENERC_KCAL];
- h6 = 902 * food_work.nutrient[LONG6] / food_work.nutrient[ENERC_KCAL];
- o  = 902 * food_work.nutrient[FAT] * options.fattyacidfactor / food_work.nutrient[ENERC_KCAL] - food_work.nutrient[SHORT6] - food_work.nutrient[LONG6] - food_work.nutrient[SHORT3] - food_work.nutrient[LONG3];
+ p3 = 900 * food_work.nutrient[SHORT3] / food_work.nutrient[ENERC_KCAL];
+ p6 = 900 * food_work.nutrient[SHORT6] / food_work.nutrient[ENERC_KCAL];
+ h3 = 900 * food_work.nutrient[LONG3] / food_work.nutrient[ENERC_KCAL];
+ h6 = 900 * food_work.nutrient[LONG6] / food_work.nutrient[ENERC_KCAL];
+ o  = 900 * (food_work.nutrient[FASAT] + food_work.nutrient[FAMS] + food_work.nutrient[FAPU] - food_work.nutrient[SHORT6] - food_work.nutrient[LONG6] - food_work.nutrient[SHORT3] - food_work.nutrient[LONG3]) / food_work.nutrient[ENERC_KCAL];
  n6 = (int) n6hufa(p3,p6,h3,h6,o,food_work.nutrient[ENERC_KCAL]);               
 fprintf(fp,"Omega-6/3 Balance %2d/%1d\n",n6 == 0 ? 0 : n6,n6 == 0 ? 0 : 100-n6);
  break;
@@ -802,7 +794,7 @@ switch (flags)
   if (! test_for_negative_zero(&food_work.nutrient[nut])) fprintf(fp,"%8.1f %-3s\n",food_work.nutrient[nut],Unit[nut]);
   else fprintf(fp,"%9s%-3s\n","(nd)"," ");
 #else
-  if (nut != VITE && nut != VITK && nut != ILE_G)
+  if (nut != VITE && nut != VITK1 && nut != ILE_G && nut != TOCPHG)
    {
    if (! test_for_negative_zero(&food_work.nutrient[nut])) fprintf(fp,"%7.1f %-3s\n",food_work.nutrient[nut],Unit[nut]);
    else fprintf(fp,"%8s%-3s\n","(nd)"," ");
@@ -927,8 +919,9 @@ m->next = po;
 
 void compute_derived_fields(struct food *food_ptr)
 {
-float ratio, realcal, alcCalFactor = 6.93;;
-food_ptr->nutrient[VITE] = (food_ptr->nutrient[VITE_ADDED] / 0.45) + ((food_ptr->nutrient[TOCPHA] - food_ptr->nutrient[VITE_ADDED]) / 0.67);
+float ratio, realcal, alcCalFactor = 6.93;
+if (!test_for_negative_zero(&food_ptr->nutrient[VITE_ADDED]) || !test_for_negative_zero(&food_ptr->nutrient[TOCPHA])) food_ptr->nutrient[VITE] = (food_ptr->nutrient[VITE_ADDED] / 0.45) + ((food_ptr->nutrient[TOCPHA] - food_ptr->nutrient[VITE_ADDED]) / 0.67);
+if (test_for_negative_zero(&food_ptr->nutrient[VITE_ADDED]) && test_for_negative_zero(&food_ptr->nutrient[TOCPHA])) food_ptr->nutrient[VITE] = NoData;
 food_ptr->nutrient[LA] = food_ptr->nutrient[F18D2CN6] > 0 ? food_ptr->nutrient[F18D2CN6] : food_ptr->nutrient[F18D2] - food_ptr->nutrient[F18D2T] - food_ptr->nutrient[F18D2TT] - food_ptr->nutrient[F18D2I] - food_ptr->nutrient[F18D2CLA];
 if (food_ptr->nutrient[LA] == 0 && test_for_negative_zero(&food_ptr->nutrient[F18D2])) food_ptr->nutrient[LA] = NoData;
 if (food_ptr->nutrient[LA] < 0) food_ptr->nutrient[LA] = 0;
@@ -940,15 +933,17 @@ if (food_ptr->nutrient[ALA] < 0) food_ptr->nutrient[ALA] = 0;
 food_ptr->nutrient[SHORT3] = food_ptr->nutrient[ALA];
 food_ptr->nutrient[SHORT3] += food_ptr->nutrient[F18D4];
 food_ptr->nutrient[LONG6] = food_ptr->nutrient[F20D2CN6];
+food_ptr->nutrient[LONG3] = food_ptr->nutrient[F20D5];
 if (food_ptr->nutrient[F20D3N3] > 0) food_ptr->nutrient[LONG3] += food_ptr->nutrient[F20D3N3];
 if (food_ptr->nutrient[F20D3N6] > 0) food_ptr->nutrient[LONG6] += food_ptr->nutrient[F20D3N6];
 if (food_ptr->nutrient[F20D3N3] == 0 && food_ptr->nutrient[F20D3N6] == 0) food_ptr->nutrient[LONG6] += food_ptr->nutrient[F20D3];
 food_ptr->nutrient[AA] = food_ptr->nutrient[F20D4];
 if (food_ptr->nutrient[F20D4N6] > 0) food_ptr->nutrient[AA] = food_ptr->nutrient[F20D4N6];
 food_ptr->nutrient[LONG6] += food_ptr->nutrient[AA];
-food_ptr->nutrient[EPA] = food_ptr->nutrient[F20D5];
-food_ptr->nutrient[LONG3] = food_ptr->nutrient[F20D5];
 food_ptr->nutrient[LONG3] += food_ptr->nutrient[F22D5];
+food_ptr->nutrient[LONG6] += food_ptr->nutrient[F22D4];
+food_ptr->nutrient[LONG3] += food_ptr->nutrient[F21D5];
+food_ptr->nutrient[EPA] = food_ptr->nutrient[F20D5];
 food_ptr->nutrient[DHA] = food_ptr->nutrient[F22D6];
 food_ptr->nutrient[LONG3] += food_ptr->nutrient[F22D6];
 if (food_ptr->nutrient[SHORT3] == 0 && test_for_negative_zero(&food_ptr->nutrient[ALA]) && test_for_negative_zero(&food_ptr->nutrient[F18D4])) food_ptr->nutrient[SHORT3] = NoData;
@@ -977,8 +972,11 @@ if ( food_ptr->prot_cal_factor == 0 && food_ptr->fat_cal_factor == 0 && food_ptr
 food_ptr->nutrient[PROT_KCAL] = food_ptr->prot_cal_factor * food_ptr->nutrient[PROCNT];
 food_ptr->nutrient[FAT_KCAL] = food_ptr->fat_cal_factor * food_ptr->nutrient[FAT];
 food_ptr->nutrient[CHO_KCAL] = food_ptr->cho_cal_factor * food_ptr->nutrient[CHOCDF];
-food_ptr->nutrient[CHO_NONFIB] = food_ptr->nutrient[CHOCDF] - food_ptr->nutrient[FIBTG];
-if (food_ptr->nutrient[CHO_NONFIB] < 0) food_ptr->nutrient[CHO_NONFIB] = 0;
+if (!test_for_negative_zero(&food_ptr->nutrient[CHOCDF]))
+ {
+ food_ptr->nutrient[CHO_NONFIB] = food_ptr->nutrient[CHOCDF] - food_ptr->nutrient[FIBTG];
+ if (food_ptr->nutrient[CHO_NONFIB] < 0) food_ptr->nutrient[CHO_NONFIB] = 0;
+ }
 }
 
 char *format_serving(char *buffer, float *ratio, struct food *food_ptr)
@@ -990,6 +988,40 @@ buffer[49] = '\0';
 return buffer;
 }
 
+struct meal *load_foodwork(int max, struct meal *meal_ptr_origin)
+{
+int meals = 0, meal = 0, count = 0;
+char meal_date[9];
+struct meal *meal_ptr = meal_ptr_origin;
+clear_work();
+if (max == 0) max = meal_count(meal_ptr);
+clear_work();
+while (meal_ptr->next != NULL && meals <= max)
+ {
+ meal_ptr = meal_ptr->next;
+ if (strcmp(meal_date,meal_ptr->meal_date) != 0 || meal != meal_ptr->meal)
+  {
+  strcpy(meal_date,meal_ptr->meal_date);
+  meal = meal_ptr->meal;
+  meals++;
+  }
+ if (meals > max) break;
+ for (count = 1; count <= *ScreenMap[options.screen] ; count++) if (! test_for_negative_zero(&FoodIndex[meal_ptr->food_no]->nutrient[ScreenMap[options.screen][count]])) food_work.nutrient[ScreenMap[options.screen][count]] = food_work.nutrient[ScreenMap[options.screen][count]] + ((options.mealsperday * meal_ptr->grams / 100 * FoodIndex[meal_ptr->food_no]->nutrient[ScreenMap[options.screen][count]]) / (float) max); 
+ if (options.screen < 2)
+  {
+  food_work.nutrient[FAT_KCAL] += ((options.mealsperday * meal_ptr->grams / 100 * FoodIndex[meal_ptr->food_no]->nutrient[FAT_KCAL]) / (float) max);
+  food_work.nutrient[PROT_KCAL] += ((options.mealsperday * meal_ptr->grams / 100 * FoodIndex[meal_ptr->food_no]->nutrient[PROT_KCAL]) / (float) max);
+  food_work.nutrient[CHO_KCAL] += ((options.mealsperday * meal_ptr->grams / 100 * FoodIndex[meal_ptr->food_no]->nutrient[CHO_KCAL]) / (float) max);
+  food_work.nutrient[SHORT3] += ((options.mealsperday * meal_ptr->grams / 100 * FoodIndex[meal_ptr->food_no]->nutrient[SHORT3]) / (float) max);
+  food_work.nutrient[LONG3] += ((options.mealsperday * meal_ptr->grams / 100 * FoodIndex[meal_ptr->food_no]->nutrient[LONG3]) / (float) max);
+  food_work.nutrient[SHORT6] += ((options.mealsperday * meal_ptr->grams / 100 * FoodIndex[meal_ptr->food_no]->nutrient[SHORT6]) / (float) max);
+  food_work.nutrient[LONG6] += ((options.mealsperday * meal_ptr->grams / 100 * FoodIndex[meal_ptr->food_no]->nutrient[LONG6]) / (float) max);
+  food_work.nutrient[ALC] += ((options.mealsperday * meal_ptr->grams / 100 * FoodIndex[meal_ptr->food_no]->nutrient[ALC]) / (float) max);
+  }
+ }
+return meal_ptr;
+}
+
 float n6hufa(float p3, float p6, float h3, float h6, float o, float c)
 {
 float pc6 = .0441, pc3 = .0555, co = 5, ks = .175, hc6 = .7, hc3 = 3;
@@ -1000,8 +1032,10 @@ float answer;
 printf("%f %f %f %f %f\n",p3,p6,h3,h6,o);
 exit(0);
 */  
-if (p3 == 0 && p6 == 0 && h3 == 0 && h6 == 0) return 0;
-if (c == 0) return 0;
+/* if (p3 == 0 && p6 == 0 && h3 == 0 && h6 == 0) return 0; */
+if (p3 < 0.00000001 && p6 < 0.00000001 && h3 < 0.00000001 && h6 < 0.00000001) return 0;
+/* if (c == 0) return 0; */
+if (c < 0.00000001) return 0;
 answer = 100 / (1 + pc6/p6 * (1 + p3/pc3 + h3/hi3 + o/co + p6/ks)) + 100 / (1 + hc6/h6 * (1 + h3/hc3));
 if (answer <= 90 && answer >= 15) return answer;
 if (answer > 90) return 90;
