@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2010 by Jim Jozwiak.
+    Copyright (C) 1996-2014 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,9 +25,15 @@
 #include <stdio.h>
 #include "nut.h"
 
-#define MAX_FOOD 9000
+#define MAX_FOOD 12000
 #define DV_COUNT 39
+#define CARBAMINO_COUNT 31
+#define MISC_COUNT 39
+#define SATMONO_COUNT 27
+#define POLYTRANS_COUNT 30
 #define GRAMS_IN_OUNCE 28.349523
+#define ALC_CAL_FACTOR 6.93
+#define MAX_SCREEN 6
 
 struct food
  {
@@ -36,13 +42,14 @@ struct food
  int   food_no;
  char  name[61];
  float qty;
- char  unit[51];
+ char  unit[81];
  int   refuse;
  float prot_cal_factor;
  float fat_cal_factor;
  float cho_cal_factor;
  float grams;
  float nutrient[NUTRIENT_COUNT];
+ char pcf;
  struct food *next;
  };
 
@@ -55,6 +62,7 @@ extern float DVBase[];
 extern float NoData;
 extern int DVMap[];
 extern int DV1Map[];
+extern int DVnotOK;
 extern int CarbAminoMap[];
 extern int MiscMap[];
 extern int SatMonoMap[];
@@ -62,15 +70,19 @@ extern int PolyTransMap[];
 extern int *ScreenMap[];
 extern char *ScreenTitle[];
 extern int FdGrpMap[];
-extern int MaxScreen;
 extern int MaxFdGrp;
 extern int LookupNutrNo[];
 extern int LookupNut[];
 extern int FoodCount;
+extern int Abbrev_Count;
+extern const char *Abbreviations[];
+
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 void initializations(void);
 int order_new_food(void);
-void order_new_food_already_sorted(void);
 int namestrcmp(char *, char *);
 int substring_finder(char *, char *);
 struct food *food_choice(char *, int);
@@ -89,6 +101,11 @@ void modify_recipe_food(int, char *);
 void modify_label_food(int, char *);
 void compute_derived_fields(struct food *);
 char *format_serving(char *, float *, struct food *);
+struct meal *load_foodwork(int, struct meal *);
 float n6hufa(float, float, float, float, float, float);
 
+#ifdef __cplusplus
+} /* closing brace for extern "C" */
+#endif
+
 #endif
