@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2010 by Jim Jozwiak.
+    Copyright (C) 1996-2014 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,8 +22,6 @@
 #ifndef MEAL_H
 #define MEAL_H
 
-#include "food.h"
-#include <stdio.h>
 
 struct meal
  {
@@ -36,6 +34,12 @@ struct meal
  };
 
 extern struct meal meal_root, theusual_root, *new_meal, *new_theusual;
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+
 void order_new_meal();
 void order_new_theusual();
 struct meal *theusual_choice(char *, char *);
@@ -46,6 +50,9 @@ struct meal *theusual_find(char *);
 struct meal *prev_meal(struct meal *);
 void modify_meal(char *, int, int, char *);
 void pcf(char *, int, char *);
+void pcfrun(void);
+void pcftweak(int, struct meal *);
+void pcfclear(struct meal *);
 void delete_meal_with_ptr(struct meal *);
 void modify_theusual(char *, int, char *);
 void delete_theusual_with_ptr(struct meal *);
@@ -55,6 +62,9 @@ int theusual_list(void);
 void meal_list(char *);
 void reindex_meals(int);
 void full_meal_reindexing(void);
-float average_cals(void);
+
+#ifdef __cplusplus
+} /* closing brace for extern "C" */
+#endif
 
 #endif
