@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2010 by Jim Jozwiak.
+    Copyright (C) 1996-2014 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,14 +28,9 @@
 #include "viewfood.h"
 #include "addfood.h"
 #include "ranking.h"
-#include "options.h"
 #include "prtmenu.h"
 #include "theusual.h"
 #include "trendy.h"
-#include <string.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
 
 void menu()
 {
@@ -85,7 +80,7 @@ for ( ; ; )
   case '9' : theusual();
              break; 
   case 'P' : 
-  case 'p' : print_menus();
+  case 'p' : print_menus(1);
              break; 
   default  : break;
   }
@@ -95,6 +90,17 @@ for ( ; ; )
 void view_nuts_menu()
 {
 int menu_choice;
+
+if (DVnotOK)
+ {
+ menu_choice = options.screen;
+ options.screen = 0;
+ load_foodwork(options.defanal,options.temp_meal_root);
+ auto_cal();
+ efa_dynamics();
+ options.screen = menu_choice;
+ }
+
 for ( ; ; )
  {
  header("NUT:  View Nutrients and Rank Foods");
@@ -134,6 +140,17 @@ for ( ; ; )
 void add_foods_menu()
 {
 int menu_choice;
+
+if (DVnotOK)
+ {
+ menu_choice = options.screen;
+ options.screen = 0;          
+ load_foodwork(options.defanal,options.temp_meal_root);
+ auto_cal();
+ efa_dynamics();
+ options.screen = menu_choice;
+ }
+
 header("NUT:  Add Foods and Modify Serving Sizes");
 printf("\n\n                           1  --  Add a Recipe\n\n");
 printf("                           2  --  Add a Labeled Food\n\n");
@@ -161,11 +178,11 @@ for ( ; ; )
  {
  header("NUT:  View Nutrients and Rank Foods");
  printf("\n      Change group of nutrients to view?\n\n\n");
- for (i = 0; i < MaxScreen; i++) printf("                    %d  --  %s\n\n",i+1,ScreenTitle[i]);
- spacer(MaxScreen*2+4);
+ for (i = 0; i < MAX_SCREEN; i++) printf("                    %d  --  %s\n\n",i+1,ScreenTitle[i]);
+ spacer(MAX_SCREEN*2+4);
  printf("\nEnter your choice (just <enter> to quit):  ");
  screen_choice = get_int();
- if (screen_choice < 1 || screen_choice > MaxScreen) return;
+ if (screen_choice < 1 || screen_choice > MAX_SCREEN) return;
  options.screen = screen_choice - 1;
  write_OPTIONS();
  view_nuts(choice);
@@ -176,81 +193,90 @@ void screen_subvert_trendy()
 {
 int screen_choice, i;
 char mode = 'd';
-mode = trendy(mode);
+
+if (DVnotOK)
+ {
+ i = options.screen;
+ options.screen = 0;
+ load_foodwork(options.defanal,options.temp_meal_root);
+ auto_cal();
+ efa_dynamics();
+ options.screen = i;
+ }
+
+mode = trendy(mode, -1);
 if (mode == 'X') return;
 for ( ; ; )
  {
  if (mode == 'd') header("NUT:  Plot Daily Trends");
  if (mode != 'd') header("NUT:  Plot Monthly Trends");
  printf("\n      Change group of nutrients to view?\n\n\n");
- for (i = 0; i < MaxScreen; i++) printf("                    %d  --  %s\n\n",i+1,ScreenTitle[i]);
- spacer(MaxScreen*2+4);
+ for (i = 0; i < MAX_SCREEN; i++) printf("                    %d  --  %s\n\n",i+1,ScreenTitle[i]);
+ spacer(MAX_SCREEN*2+4);
  printf("\nEnter your choice (just <enter> to quit):  ");
  screen_choice = get_int();
- if (screen_choice < 1 || screen_choice > MaxScreen) return;
+ if (screen_choice < 1 || screen_choice > MAX_SCREEN) return;
  options.screen = screen_choice - 1;
  write_OPTIONS();
- mode = trendy(mode);
+ mode = trendy(mode, -1);
  }
 }
 
 void personal_menu()
 {
 int menu_choice;
-char calflag[40];
-char pcproteinflag[40];
-char pccarbflag[40];
-char pcsatfatflag[40];
-char abproteinflag[40];
-char abcarbflag[40];
-char abfiberflag[40];
+options.comparison = 0;
+ 
+menu_choice = options.screen;
+options.screen = 0;          
+load_foodwork(options.defanal,options.temp_meal_root);
+auto_cal();
+efa_dynamics();
+options.screen = menu_choice;
+
 for ( ; ; )
  {
- sprintf(calflag,"%s  %5.1f %s",(options.locknuts[ENERC_KCAL] && options.autocal == 0 ? "(LOCKED:" : options.autocal > 0 ? "(AUTO-SET:"  : "(SET:"),options.abnuts[ENERC_KCAL],"kc)");
- sprintf(pcproteinflag,"%s %5.1f%s",options.locknuts[PROCNT] && options.pcprotein > 0 ? "(LOCKED:" : "(SET:",options.pcprotein,"%)");
- sprintf(pccarbflag,"%s %5.1f%s",options.locknuts[CHOCDF] && options.pccarb > 0 ? "(LOCKED:" : "(SET:",options.pccarb,"%)");
- sprintf(pcsatfatflag,"%s %5.1f%s",options.locknuts[FASAT] ? "(LOCKED:" : "(SET:",options.pcsatfat,"%)");
- sprintf(abproteinflag,"%s  %5.1f %s",options.locknuts[PROCNT] && options.abnuts[PROCNT] > 0 ? "(LOCKED:" : "(SET:",options.abnuts[PROCNT],"g)");
- if (options.abnuts[CHOCDF] >= 0) sprintf(abcarbflag,"%s  %5.1f %s",options.locknuts[CHOCDF] && options.abnuts[CHOCDF] > 0 ? "(LOCKED:" : "(SET:",options.abnuts[CHOCDF],"g)");
- else sprintf(abcarbflag,"%s %5.1f %s","(LOCKED:  Fiber +",-1 * options.abnuts[CHOCDF],"g)");
- sprintf(abfiberflag,"%s %5.1f %s",options.locknuts[FIBTG] ? "(LOCKED:" : "(SET:",options.abnuts[FIBTG],"g)");
- header("NUT:  Personal Options");
- printf("                1  --  Change Calorie Level %s\n\n",options.abnuts[ENERC_KCAL] != 2000 || options.locknuts[ENERC_KCAL] || options.autocal > 0 ? calflag : "(default)");
- if (options.n6hufa == 0 && options.abnuts[FAPU] == 0) printf("                2  --  Essential Fatty Acid Options (default)\n\n");
- else if (options.locknuts[FAPU] == 1) printf("                2  --  Essential Fatty Acid Options (LOCKED:  %3.1f g)\n\n",options.abnuts[FAPU]);
- else if (options.n6hufa == 90 && options.abnuts[FAPU] == 0) printf("                2  --  Essential Fatty Acid Options (SET:  off)\n\n");
- else if (options.n6hufa > 0 && options.abnuts[FAPU] == 0) printf("                2  --  Essential Fatty Acid Options (SET:  %2.0f/%2.0f)\n\n",options.n6hufa,100-options.n6hufa);
- else if (options.abnuts[FAPU] > 0) printf("                2  --  Essential Fatty Acid Options (SET:  %3.1f g)\n\n",options.abnuts[FAPU]);
- printf("                3  --  Saturated Fat Percentage %s\n\n",options.pcsatfat ? pcsatfatflag : "(default)");
- printf("                4  --  Fiber Absolute Amount %s\n\n",options.abnuts[FIBTG] ? abfiberflag : "(default)");
- printf("                5  --  Carbohydrate Percentage %s\n\n",options.pccarb ? pccarbflag : "(default)");
- printf("                6  --  Protein Percentage %s\n\n",options.pcprotein ? pcproteinflag : "(default)");
- printf("                7  --  Carbohydrate Absolute Amount %s\n\n",options.abnuts[CHOCDF] ? abcarbflag : "(default)");
- printf("                8  --  Protein Absolute Amount %s\n\n",options.abnuts[PROCNT] ? abproteinflag : "(default)");
- printf("                0  --  Restore All Defaults\n\n");
- printf("                W  --  Weight Log Regression\n");
- spacer(19);
+ header("NUT:  Set Personal Options");
+ printf("            1  --  Calories              ");
+ current_settings(1);
+ printf("            2  --  Total Fat             ");
+ current_settings(2);
+ printf("            3  --  Protein               ");
+ current_settings(3);
+ printf("            4  --  Non-Fiber Carb        ");
+ current_settings(4);
+ printf("            5  --  Fiber                 ");
+ current_settings(5);
+ printf("            6  --  Saturated Fat         ");
+ current_settings(6);
+ printf("            7  --  Essential Fatty Acids ");
+ current_settings(7);
+ printf("            8  --  Omega-6/3 Balance     ");
+ current_settings(8);
+ printf("            0  --  Restore All Defaults\n\n");
+ printf("            W  --  Weight Log Regression\n\n");
+ spacer(20);
  printf("\nEnter your choice (just <enter> to quit):  ");
  menu_choice = get_char();
  switch (menu_choice)
   {
-  case '1' : personal_cal();
+  case '1' : set_calories();
              break; 
-  case '2' : efa_options();
+  case '2' : set_fat();
              break; 
-  case '3' : satfat_percent();
+  case '3' : set_protein();
              break; 
-  case '4' : fiber_absolute();
+  case '4' : set_carb();
              break; 
-  case '5' : carb_percent();
+  case '5' : set_fiber();
              break; 
-  case '6' : protein_percent();
+  case '6' : set_sat();
              break; 
-  case '7' : carb_absolute();
+  case '7' : set_efa();
              break; 
-  case '8' : protein_absolute();
+  case '8' : set_n6();
              break; 
-  case '0' : restore_defaults(1);
+  case '0' : restore_defaults();
              break; 
   case 'w' :
   case 'W' : weight_log();
