@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2010 by Jim Jozwiak.
+    Copyright (C) 1996-2014 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,6 +22,10 @@
 #ifndef MENU_H
 #define MENU_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 void menu(void);
 void view_nuts_menu(void);
 void add_foods_menu(void);
@@ -29,4 +33,8 @@ void personal_menu(void);
 void screen_subvert_rank(int);
 void screen_subvert_trendy(void);
 
+#ifdef __cplusplus
+} /* closing brace for extern "C" */
+#endif
+
 #endif
