@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2010 by Jim Jozwiak.
+    Copyright (C) 1996-2014 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -33,45 +33,38 @@ struct opt
  int defanalrec;
  int screen;
  int custom;
- float pcprotein;
- float pccarb;
- float pcsatfat;
- float carbcalpergm;
- float protcalpergm;
- float fatcalpergm;
- float fattyacidfactor;
  float n6hufa;
- float epadhamax;
+ float lastwlw;
+ float lastwlbfp;
+ char lastwldate[9];
+ int wltweak;
+ int wlpolarity;
  int next_recipe;
- int locknuts[NUTRIENT_COUNT];
  float abnuts[NUTRIENT_COUNT];
  int mealsperday;
  char grams;
  char autocal;
+ char comparison;
  struct meal *temp_meal_root;
  };
 
-#define ALA_FACTOR    6
+extern float DefaultTarget, DefaultEPADHA;
 
 #define DELOPT        1000 
 #define DEFANAL       1001
 #define SCREEN        1002
-#define CUSTOM        1003
-#define PCPROTEIN     1004
-#define PCCARB        1005
-#define PCSATFAT      1006
 #define NEXT_RECIPE   1008
 #define MEALSPERDAY   1009
 #define GRAMS         1010 
 #define AUTOCAL       1011
-#define PROTCALPERGM  1012
-#define CARBCALPERGM  1013
-#define FATCALPERGM   1014
-#define FATTYACIDFACTOR 1015
 #define N6HUFA        1016
-#define EPADHAMAX     1018
 #define DEFANALANAL   1019
 #define DEFANALREC    1020
+#define LASTWLW       1021
+#define LASTWLBFP     1022
+#define LASTWLDATE    1023
+#define WLTWEAK       1024
+#define WLPOLARITY    1025
 
 #define OPT_CHO_NONFIB 2000
 #define OPT_LA         2001
@@ -84,26 +77,33 @@ struct opt
 #define OPT_VITE       2008
 
 extern struct opt options;
-extern int mealdb_mealsperday;
+
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 void initialize_options(void);
-void personal_cal(void);
-void efa_options(void);
-void efa_method(void);
-void protein_percent(void);
-void carb_percent(void);
-void satfat_percent(void);
-void protein_absolute(void);
-void carb_absolute(void);
-void fiber_absolute(void);
-void auto_cal(float *, int);
+void current_settings(int);
+void set_calories(void);
+void set_fat(void);
+void set_protein(void);
+void set_carb(void);
+void set_fiber(void);
+void set_sat(void);
+void set_efa(void);
+void set_n6(void);
+void auto_cal(void);
 void auto_del(void);
 void screen(void);
 void screen_previous(void);
 void get_cals(float *);
 void new_nut_levels(void);
-void restore_defaults(int);
-void efa_dynamics();
+void restore_defaults(void);
+void efa_dynamics(void);
 void weight_log();
 
+#ifdef __cplusplus
+} /* closing brace for extern "C" */
+#endif
+ 
 #endif
