@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2010 by Jim Jozwiak.
+    Copyright (C) 1996-2014 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,34 +19,46 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
-#include "prtmenu.h"
-#include "food.h"
 #include "options.h"
 #include "util.h"
-#include "db.h"
-#include <stdio.h>
-#include <stdlib.h>
 #include <string.h>
 
-void print_menus()
+void print_menus(int console)
 {
 FILE *fp;
 struct meal *meal_ptr = options.temp_meal_root;
 int firstpage = 1, count, mealcount = 0;
 char last_meal_date[9], last_meal = '0', newpage = 0x0c;
+
+if (DVnotOK)
+ {
+ count = options.screen;
+ options.screen = 0;
+ load_foodwork(options.defanal,options.temp_meal_root);
+ auto_cal();
+ efa_dynamics();
+ options.screen = count;
+ }
+
 if (meal_ptr->next == NULL)
  {
- header("NUT:  Print Menus from Meal Database");
- spacer(0);
- printf("\nThere are no meals in database.  Press <enter> to continue..."); 
- firstpage = get_int();
+ if (console)
+  {
+  header("NUT:  Print Menus from Meal Database");
+  spacer(0);
+  printf("\nThere are no meals in database.  Press <enter> to continue..."); 
+  firstpage = get_int();
+  }
  return;
  }
 if ((fp = fopen("menus.txt","w")) == NULL)
  {
- printf("Can't open file \"menus.txt\" to write.\n");
- printf("Press <enter> to continue...");
- firstpage = get_int();
+ if (console)
+  {
+  printf("Can't open file \"menus.txt\" to write.\n");
+  printf("Press <enter> to continue...");
+  firstpage = get_int();
+  }
  return;
  }
 strcpy(last_meal_date,"");
@@ -83,9 +95,12 @@ food_display(fp);
 clear_work();
 fclose(fp);
 /* meal_export(); */
-header("NUT:  Print Menus from Meal Database");
-spacer(0);
-printf("\nMenus printed to \"menus.txt\".  Press <enter> to continue..."); 
-firstpage = get_int();
+if (console)
+ {
+ header("NUT:  Print Menus from Meal Database");
+ spacer(0);
+ printf("\nMenus printed to \"menus.txt\".  Press <enter> to continue..."); 
+ firstpage = get_int();
+ }
 return;
 }
