@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2010 by Jim Jozwiak.
+    Copyright (C) 1996-2014 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,10 +25,18 @@
 extern int Minut;
 extern int Fdgrp;
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 void view_nuts(int);
 void rank_foods(int,int);
 int max_array(float []);
 void nut_list(void);
 void fdgrp_list(void);
 
+#ifdef __cplusplus
+} /* closing brace for extern "C" */
+#endif
+
 #endif
