@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2010 by Jim Jozwiak.
+    Copyright (C) 1996-2014 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,14 +20,9 @@
 */
 
 #include "remmeal.h"
-#include "food.h"
 #include "util.h"
 #include "db.h"
 #include "options.h"
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <time.h>
 
 void remove_meals()
 {
