@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2010 by Jim Jozwiak.
+    Copyright (C) 1996-2014 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,7 +22,15 @@
 #ifndef REMMEAL_H
 #define REMMEAL_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 void remove_meals(void);
 void remove_meals_menu(void);
 
+#ifdef __cplusplus
+} /* closing brace for extern "C" */
+#endif
+
 #endif
