@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2010 by Jim Jozwiak.
+    Copyright (C) 1996-2014 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,12 +19,9 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
-#include "theusual.h"
-#include "food.h"
 #include "options.h"
 #include "util.h"
 #include "db.h"
-#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
@@ -39,6 +36,17 @@ char buff[128];
 char *token;
 int c, d, modfood, junk;
 float ratio = 0, one = 1;
+
+if (DVnotOK)
+ {
+ junk = options.screen;
+ options.screen = 0;          
+ load_foodwork(options.defanal,options.temp_meal_root);
+ auto_cal();
+ efa_dynamics();
+ options.screen = junk;
+ }
+
 key[0] = '\0';
 header("NUT:  Record \"The Usual\"--Customary Meals");
 #ifndef DOS
@@ -107,7 +115,7 @@ for ( ; ; )
   }
  if (ratio != 0 && ratio != -383838)
   {
-  if ((new_theusual = malloc(sizeof(struct food))) == NULL)
+  if ((new_theusual = malloc(sizeof(struct meal))) == NULL)
    {
    printf("We are out of memory.  Bummer.\n");
    abort();
