@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2010 by Jim Jozwiak.
+    Copyright (C) 1996-2014 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,16 +20,14 @@
 */
 
 #include "trendy.h"
-#include "food.h"
 #include "options.h"
 #include "util.h"
 #include "ranking.h"
-#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <math.h>
 
-char trendy(char mode)
+char trendy(char mode, int story)
 {
 int nutnum, count;
 int caldv = 0, nutdv = 0, linecount, graphwidth = 35, daycount;
@@ -75,12 +73,16 @@ if (meal_count(&meal_root) == 0)
  return 'X';
  }
 
-header("NUT:  Plot Daily and Monthly Trends");
-nut_list();
-printf("\nType number of nutrient to graph and \"d\" or \"m\" (or <enter> to quit):  ");
-nutnum = get_trendy(&mode);
-if (nutnum < 1 || nutnum > *ScreenMap[options.screen]) return mode;
-nutnum = ScreenMap[options.screen][nutnum];
+if (story == -1)
+ {
+ header("NUT:  Plot Daily and Monthly Trends");
+ nut_list();
+ printf("\nType number of nutrient to graph and \"d\" or \"m\" (or <enter> to quit):  ");
+ nutnum = get_trendy(&mode);
+ if (nutnum < 1 || nutnum > *ScreenMap[options.screen]) return mode;
+ nutnum = ScreenMap[options.screen][nutnum];
+ }
+else nutnum = story;
 
 ep_ptr = &eachmonth;
 saveep_ptr = &eachmonth;
@@ -322,6 +324,24 @@ for ( ; ; )
  spacer(linecount+2);
  printf("\nPress <enter> to quit...");
  count = get_int();
+ if (story != -1)
+  {
+  saveep_ptr = eachmonth.next;
+  while (saveep_ptr != NULL)
+   {
+   ep_ptr = saveep_ptr;
+   saveep_ptr = ep_ptr->next;
+   free(ep_ptr);
+   }
+  saveep_ptr = eachday.next;
+  while (saveep_ptr != NULL)
+   {
+   ep_ptr = saveep_ptr;
+   saveep_ptr = ep_ptr->next;
+   free(ep_ptr);
+   }
+  return mode;
+  }
  if (mode == 'm') header("NUT:  Plot Monthly Trends");
  if (mode == 'd') header("NUT:  Plot Daily Trends");
  nut_list();
