@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2010 by Jim Jozwiak.
+    Copyright (C) 1996-2014 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,7 +22,15 @@
 #ifndef TRENDY_H
 #define TRENDY_H
 
-char trendy(char);
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+char trendy(char, int);
 int get_trendy(char *);
 
+#ifdef __cplusplus
+} /* closing brace for extern "C" */
+#endif
+
 #endif
