@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2010 by Jim Jozwiak.
+    Copyright (C) 1996-2014 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,12 +19,10 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
-#include "util.h"
 #include "options.h"
 #include "db.h"
 #include <string.h>
 #include <stdlib.h>
-#include <stdio.h>
             
 /* replacement compatibility C99-style math.h functions
    tested with gcc on: i386, amd64, ia64, powerpc, sparc, s390, hppa, alpha
@@ -59,7 +57,7 @@ int wjl_isnan(float x) {
 int wjl_isinf(float x) {
   void *tmp = &x;
   wjl_ieee754_float_t *f = (wjl_ieee754_float_t *)tmp;
-  if ((f->exponent = 0xff) && (f->mantissa == 0)) {
+  if ((f->exponent == 0xff) && (f->mantissa == 0)) {
     if (f->sign == 0) return 1;
     else return -1;
   }
@@ -102,7 +100,7 @@ char buff[128];
 float lastresult = *result;
 float dividend, divisor;
 if ( lastresult <= 0 ) lastresult = 1;
-printf("\n# servings, #g grams, #o oz, #c calories, \"b\" back, \"d\" alt:  ");
+printf("\n# servings, #g grams, #o oz, #c calories, \"b\" back:  ");
 fgets(buff,128,stdin);
 if (strchr(buff,'g') != NULL) 
  {
@@ -135,11 +133,13 @@ if (qtystring == NULL) return 0;
 if (strchr(qtystring,'g') != NULL) 
  {
  options.grams = 1;
+ write_OPTIONS();
  return atof(qtystring);
  }
 else if (strchr(qtystring,'o') != NULL) 
  {
  options.grams = 0;
+ write_OPTIONS();
  return atof(qtystring) * GRAMS_IN_OUNCE;
  }
 else if (strchr(qtystring,'c') != NULL) return atof(qtystring) * 100 / food_ptr->nutrient[ENERC_KCAL];
@@ -150,7 +150,6 @@ else if (strchr(qtystring,'/') != NULL)
  return food_ptr->grams * dividend / divisor;
  }
 else return atof(qtystring) * food_ptr->grams;
-write_OPTIONS();
 }
 
 int evaluate_action(char *actionstring)
