@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2010 by Jim Jozwiak.
+    Copyright (C) 1996-2014 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,6 +24,10 @@
 
 #include "food.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 int get_char(void);
 int get_int(void);
 float get_float();
@@ -42,4 +46,8 @@ void key_decode(char *, char *);
 void test_signsense(float *);
 int test_for_negative_zero(float *);
 
+#ifdef __cplusplus
+} /* closing brace for extern "C" */
+#endif
+
 #endif
