@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2010 by Jim Jozwiak.
+    Copyright (C) 1996-2014 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,16 +19,25 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
-#include "viewfood.h"
-#include "food.h"
+#include "options.h"
 #include "util.h"
-#include <stdlib.h> 
-#include <stdio.h> 
 
 void view_foods()
 {
 struct food *food_ptr = NULL;
 float ratio = -1, one = 1;
+int savescreen;
+
+if (DVnotOK)
+ {
+ savescreen = options.screen;
+ options.screen = 0;          
+ load_foodwork(options.defanal,options.temp_meal_root);
+ auto_cal();
+ efa_dynamics();
+ options.screen = savescreen;
+ }
+
 key_clean();
 for ( ; ; )
  {
@@ -44,7 +53,7 @@ for ( ; ; )
  else food_show(food_ptr,&one);
  get_qty(&ratio, &(food_ptr->grams), &(food_ptr->nutrient[ENERC_KCAL]));
  if (ratio == -383838) key_take();
- else if (ratio > 0 && ratio > 100) ratio = 100;
+/* else if (ratio > 0 && ratio > 100) ratio = 100; */
  else if (ratio == 0) key_clean();
  }
 }
